/*!
 * Copyright (c) Microsoft. All rights reserved.
 * Licensed under the MIT license. See LICENSE file in the project.
 */ /* eslint-disable @typescript-eslint/no-var-requires */ "use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    getCjsConfiguration: function() {
        return getCjsConfiguration;
    },
    getEsmConfiguration: function() {
        return getEsmConfiguration;
    },
    getNodeConfiguration: function() {
        return getNodeConfiguration;
    }
});
const _fs = require("fs");
const _path = require("path");
const _createBabelConfig = _export_star(require("./createBabelConfig.js"), exports);
const _getBrowsersList = require("./getBrowsersList.js");
function _export_star(from, to) {
    Object.keys(from).forEach(function(k) {
        if (k !== "default" && !Object.prototype.hasOwnProperty.call(to, k)) {
            Object.defineProperty(to, k, {
                enumerable: true,
                get: function() {
                    return from[k];
                }
            });
        }
    });
    return from;
}
const loadJson = require;
const cwd = process.cwd();
const packageJsonPath = (0, _path.join)(cwd, "package.json");
const packageJson = (0, _fs.existsSync)("package.json") ? require(packageJsonPath) : {};
const babelEsmOverride = (0, _path.join)(cwd, "babel.esm.js");
const babelCjsOverride = (0, _path.join)(cwd, "babel.cjs.js");
const useBuiltIns = packageJson.useBuiltIns || "usage";
const corejs = packageJson.corejs || (useBuiltIns ? {
    version: 3,
    proposals: false
} : undefined);
function getCjsConfiguration(env, spec = {}) {
    var _packageJson;
    // ALlows users to override default cjs emission
    // during build by defining 'babel.cjs.js'
    if ((0, _fs.existsSync)(babelCjsOverride)) {
        return loadJson(babelCjsOverride);
    }
    return (0, _createBabelConfig.createBabelConfig)({
        modules: "cjs",
        targets: (0, _getBrowsersList.getBrowsersList)(env, (_packageJson = packageJson) === null || _packageJson === void 0 ? void 0 : _packageJson.browserslist),
        useBuiltIns,
        corejs,
        ...spec
    });
}
function getEsmConfiguration(env, spec = {}) {
    // ALlows users to override default esm emission
    // during build by defining 'babel.esm.js'
    if ((0, _fs.existsSync)(babelEsmOverride)) {
        return loadJson(babelEsmOverride);
    }
    return (0, _createBabelConfig.createBabelConfig)({
        modules: "esm",
        targets: (0, _getBrowsersList.getBrowsersList)(env, packageJson.browserslist),
        useBuiltIns,
        corejs,
        ...spec
    });
}
function getNodeConfiguration(spec = {}) {
    return (0, _createBabelConfig.createBabelConfig)({
        modules: "cjs",
        targets: {
            node: "current"
        },
        presets: [
            require("@babel/preset-typescript"),
            require("@babel/preset-react")
        ],
        ...spec
    });
}

//# sourceMappingURL=index.js.map